@@ -15,7 +15,7 @@ def read_pickle(filename):
 
 def write_pickle(data, filename):
     with open(filename, 'wb') as f:
-        return pickle.dump(data, f)
+        return pickle.dump(data, f, protocol=5)
 
 
 def read_data(filename):
@@ -54,8 +54,8 @@ def write_datalist(datalist, filename):
 def append_datalist(datalist, filename):
     try:
         assert type(datalist) == list
-        with open(filename, 'w', encoding='utf-8') as f:
+        with open(filename, 'a', encoding='utf-8') as f:
             f.writelines([line + '\n' for line in datalist])
         return True
     except:
-        return traceback.print_exc()
\ No newline at end of file
+        return traceback.print_exc()
